/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.apache.commons.lang.builder.ReflectionToStringBuilder;

abstract class ApiObject {

    private final String id;

    protected ApiObject(String id) {
        this.id = id;
    }

    public String getId() {
        return id;
    }

    @Override
    public String toString() {
        return ReflectionToStringBuilder.reflectionToString(this);
    }

    @Override
    public int hashCode() {
        return getId().hashCode();
    }

    @Override
    public boolean equals(Object thatObj) {
        if (this == thatObj)
            return true;

        if (thatObj == null)
            return false;

        if (getClass() != thatObj.getClass())
            return false;

        if (!(thatObj instanceof ApiObject))
            return false;

        if (((ApiObject) thatObj).getId() == null) {
            return false;
        }

        return getId() != null && getId().equals(((ApiObject) thatObj).getId());
    }
}
