/**
 *   Copyright 2010 Guardian News And Media
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

enum ApiParameter {

    q,
    page,
    pageSize,
    format,
    type,
    showTags,
    showFields,
    section,
    tag,
    showRefinements,
    fromDate,
    toDate,
    apiKey("api-key");

    private final String urlParam;

    private ApiParameter() {
        urlParam = null;
    }

    private ApiParameter(String urlParameterOverride) {
        urlParam = urlParameterOverride;
    }

    public String getUrlParam() {
        if (urlParam == null)
            return name();

        return urlParam;
    }

    public static ApiParameter findByUrlParam(String urlParam) {
        for (ApiParameter apiParameter : ApiParameter.values())
            if (apiParameter.getUrlParam().equals(urlParam))
                return apiParameter;

        throw new IllegalStateException("Cant find ApiParameter by param: " + urlParam);
    }
}
