/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.apache.commons.lang.builder.ReflectionToStringBuilder;

import java.io.Serializable;

public abstract class ApiResponse<T extends ApiQuery> implements Serializable {

    protected final ApiQuery query;

    private String json;
    private Integer numberOfResults;
    private UserTier userTier;
    private ResponseStatus status;

    protected ApiResponse(T query) {
        status = ResponseStatus.error;
        this.query = query;
    }

    @SuppressWarnings("unchecked")
    public T getQuery() {
        return (T) query;
    }

    public boolean isResponseOk() {
        return ResponseStatus.ok.equals(status);
    }

    public ResponseStatus getStatus() {
        return status;
    }

    public Integer getTotalNumberOfResults() {
        return numberOfResults;
    }

    public UserTier getUserTier() {
        return userTier;
    }

    public String getJson() {
        return json;
    }

    @Override
    public String toString() {
        return ReflectionToStringBuilder.toString(this);
    }

    void setUserTier(UserTier userTier) {
        this.userTier = userTier;
    }

    void setStatus(ResponseStatus status) {
        this.status = status;
    }

    void setTotalNumberOfResults(Integer numberOfResults) {
        this.numberOfResults = numberOfResults;
    }

    void setJson(String json) {
        this.json = json;
    }
}

