/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.net.MalformedURLException;
import java.net.URL;

import static com.gu.openplatform.contentapi.GuardianApiHostProvider.getGuardianApiHost;

abstract class ApiUrlTranslator {

    private static final Logger logger = LoggerFactory.getLogger(ApiUrlTranslator.class);

    static boolean canTranslateUrl(String url) {
        return (url != null) && (url.startsWith("http://www.guardian.co.uk/")
                || url.startsWith("/")
                || url.startsWith("www.guardian.co.uk/"));
    }

    static boolean canTranslateUrl(URL url) {
        return canTranslateUrl(url.toString());
    }

    static URL translateToApiUrl(URL from) {
        return translateToApiUrl(from.toString());
    }

    static URL translateToApiUrl(String sourceUrl) {
        if (!canTranslateUrl(sourceUrl))
            throw new RuntimeException("Cannot translate URL: " + sourceUrl + " into API URL");

        if (sourceUrl.indexOf("http://www.guardian.co.uk/") != -1)
            return makeUrl(sourceUrl.replace("http://www.guardian.co.uk", getGuardianApiHost()));

        if (sourceUrl.indexOf("www.guardian.co.uk/") != -1)
            return makeUrl(sourceUrl.replace("www.guardian.co.uk", getGuardianApiHost()));

        if (!sourceUrl.startsWith("/"))
            return makeUrl(getGuardianApiHost().concat("/").concat(sourceUrl));

        return makeUrl(getGuardianApiHost().concat(sourceUrl));
    }

    private static URL makeUrl(String to) {
        URL toUrl;

        try {
            toUrl = new URL(to);
        } catch (MalformedURLException e) {
            logger.error("Cannot create URL " + to, e);
            throw new RuntimeException(e);
        }

        return toUrl;
    }

}
