/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

abstract class GuardianApiHostProvider {

    private static final Logger logger = LoggerFactory.getLogger(GuardianApiHostProvider.class);

    private static final String defaultHost = "http://content.guardianapis.com";
    private static final String apiProperties = "/guardian-api.properties";
    private static final String hostPropertyKey = "apiHost";

    private static String cachedApiHost;

    static String getGuardianApiHost() {
        if (cachedApiHost == null)
            resolveHost();

        return cachedApiHost;
    }

    private static void resolveHost() {
        Properties properties = new Properties();

        try {
            InputStream stream = GuardianApiHostProvider.class.getResourceAsStream(apiProperties);

            if (stream != null)
                properties.load(stream);
        }
        catch (IOException e) {
            logger.info("No local config file found");
        }

        cachedApiHost = properties.getProperty(hostPropertyKey);

        if (cachedApiHost == null)
            cachedApiHost = defaultHost;

        logger.info("Using API host: " + cachedApiHost);
    }

}
