/**
 *   Copyright 2010 Guardian News And Media
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.net.URL;

public class HttpClient {

    private static final Logger logger = LoggerFactory.getLogger(HttpClient.class);

    private final ApiUrlFactory apiUrlFactory;
    private final HttpQueryExecutor httpQueryExecutor;

    public HttpClient(ApiUrlFactory apiUrlFactory, HttpQueryExecutor httpQueryExecutor) {
        this.apiUrlFactory = apiUrlFactory;
        this.httpQueryExecutor = httpQueryExecutor;
    }

    String executeQuery(String path, ApiQuery<?> apiQuery) throws HttpException {
        String responseAsString;
        URL url = apiUrlFactory.constructApiUrl(path, apiQuery);

        try {
            responseAsString = httpQueryExecutor.execute(url);
        }
        catch (Exception e) {
            logger.error("Could not get url: " + url.toString());
            throw new HttpException(e);
        }

        return responseAsString;
    }
}
