/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import net.sf.json.JSONException;
import net.sf.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ItemJsonParser extends JsonParser {

    private static final Logger logger = LoggerFactory.getLogger(ItemJsonParser.class);

    @Override
    void parseJson(String json, ApiResponse result) {
        super.parseJson(json, result);

        try {
            JSONObject response = extractTopLevelResponse(result, json);
            populateItem((ItemResult) result, response);
        }
        catch (JSONException e) {
            logger.error("Could not parse JSON", e);
            result.setStatus(ResponseStatus.error);
        }
    }

    private void populateItem(ItemResult itemResult, JSONObject response) {
        if (response.has("content"))
            itemResult.addContent(parseContent(response.getJSONObject("content")));
    }
}
