/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import java.net.URL;
import java.util.Map;
import java.util.Set;

public class ItemQuery extends ApiQuery<ItemQuery> implements ContentQueryParameters<ItemQuery> {

    private final ContentQueryParametersMixin<ItemQuery> contentQueryParameters = new ContentQueryParametersMixin<ItemQuery>(this);

    private String url;

    public ItemQuery(HttpClient httpClient, ItemJsonParser jsonParser) {
        super(httpClient, jsonParser);
    }

    @Override
    public ItemResult execute() {
        ItemResult result = new ItemResult(this);

        try {
            jsonParser.parseJson(httpClient.executeQuery(url, this), result);
        }
        catch (HttpException e) {
            result.setStatus(ResponseStatus.error);
        }

        return result;
    }

    @Override
    protected void fillInApiParameters(Map<ApiParameter, Object> parameters) {
        contentQueryParameters.fillInApiParameters(parameters);
    }

    public Set<? extends ApiUrlParameter> getFieldsToFind() {
        return contentQueryParameters.getFieldsToFind();
    }

    public Set<TagType> getTagTypesToFind() {
        return contentQueryParameters.getTagTypesToFind();
    }

    public boolean isRetrievingAllFields() {
        return contentQueryParameters.isRetrievingAllFields();
    }

    @Override
    public ItemQuery showAllTagTypes() {
        return contentQueryParameters.showAllTagTypes();
    }

    @Override
    public ItemQuery showField(String... fieldNames) {
        return contentQueryParameters.showField(fieldNames);
    }

    @Override
    public ItemQuery showField(FieldType... fieldTypes) {
        return contentQueryParameters.showField(fieldTypes);
    }

    @Override
    public ItemQuery showTagTypes(String... tagIds) {
        return contentQueryParameters.showTagTypes(tagIds);
    }

    @Override
    public ItemQuery showTagTypes(TagType... tags) {
        return contentQueryParameters.showTagTypes(tags);
    }

    public ItemQuery url(String url) {
        this.url = url;
        return this;
    }

    public ItemQuery url(URL url) {
        url(url.toString());
        return this;
    }

    @Override
    public ItemQuery allFields() {
        return contentQueryParameters.allFields();
    }
}
