package com.gu.openplatform.contentapi;

import java.util.Iterator;

public class PageQueryIterable<T extends PaginatedSearchQuery<T>, R extends PaginatedSearchResult<T>> implements Iterable<T> {

    private final R tagSearchResult;

    public PageQueryIterable(R searchResult) {
        this.tagSearchResult = searchResult;
    }

    @Override
    public Iterator<T> iterator() {
        return new SearchPageResultIterator();
    }

    private class SearchPageResultIterator implements Iterator<T> {

        private int currentPage = tagSearchResult.getCurrentPage();

        @Override
        public boolean hasNext() {
            return currentPage < tagSearchResult.getNumberOfPages();
        }

        @Override
        public T next() {
            if (!hasNext())
                throw new IllegalStateException("next called on iterator with no more pages");

            currentPage = currentPage + 1;
            return tagSearchResult.getQuery().cloneForNextPageQuery(currentPage);
        }

        @Override
        public void remove() {
            throw new UnsupportedOperationException();
        }
    }
}
