/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

public abstract class PaginatedSearchResult<T extends PaginatedSearchQuery> extends ApiResponse<T> {

    private Integer startIndex;
    private Integer pageSize;
    private Integer currentPage;
    private Integer pages;

    @SuppressWarnings("unchecked")
    protected PaginatedSearchResult(T query) {
        super(query);
    }

    public Integer getNumberOfPages() {
        return pages;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public Integer getStartIndex() {
        return startIndex;
    }

    public Integer getCurrentPage() {
        return currentPage;
    }

    @SuppressWarnings("unchecked")
    public Iterable<T> getResultPageQueries() {
        return new PageQueryIterable(this);
    }

    @SuppressWarnings("unchecked")
    public T getPageQuery(Integer page) {
        if (page > getNumberOfPages())
            throw new IllegalStateException("Cannot page to a page that does not exist");

        return (T) ((PaginatedSearchQuery) query).cloneForNextPageQuery(page);
    }

    void setStartIndex(Integer startIndex) {
        this.startIndex = startIndex;
    }

    void setCurrentPage(Integer currentPage) {
        this.currentPage = currentPage;
    }

    void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    void setPages(Integer pages) {
        this.pages = pages;
    }


}
