/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import net.sf.json.JSONException;
import net.sf.json.JSONObject;

import java.util.Iterator;

public class SearchJsonParser extends PaginatedJsonParser {

    @Override
    void parseJson(String json, ApiResponse result) {
        super.parseJson(json, result);

        try {
            JSONObject response = extractTopLevelResponse(result, json);
            populateContentItems((ContentSearchResult) result, response);
            populateRefinements((ContentSearchResult) result, response);
        }
        catch (JSONException e) {
            result.setStatus(ResponseStatus.error);
        }
    }

    @Override
    protected void populateCoreResponseFields(ApiResponse apiResponse, JSONObject jsonResponse) {
        super.populateCoreResponseFields(apiResponse, jsonResponse);
        ((ContentSearchResult) apiResponse).setOrderBy(OrderBy.valueOf(jsonResponse.getString("orderBy")));
    }

    @SuppressWarnings("unchecked")
    private void populateRefinements(ContentSearchResult contentSearchResult, JSONObject response) {
        if (response.has("refinementGroups")) {
            Iterator<JSONObject> iterator = response.getJSONArray("refinementGroups").iterator();

            while (iterator.hasNext())
                fillInRefinementGroup(contentSearchResult, iterator.next());
        }
    }

    @SuppressWarnings("unchecked")
    private void fillInRefinementGroup(ContentSearchResult contentSearchResult, JSONObject refinementGroup) {
        TagType refinementType = TagType.typeFor(refinementGroup.getString("type"));

        if (refinementGroup.has("refinements")) {
            Iterator<JSONObject> iterator = refinementGroup.getJSONArray("refinements").iterator();

            while (iterator.hasNext()) {
                JSONObject refinementJson = iterator.next();

                contentSearchResult.addRefinement(
                        new Refinement(
                                refinementType,
                                refinementJson.getString("id"),
                                refinementJson.getInt("count"),
                                refinementJson.getString("displayName")));
            }
        }
    }

    @SuppressWarnings("unchecked")
    private void populateContentItems(ContentSearchResult contentSearchResponse, JSONObject response) {
        if (response.has("results")) {
            Iterator<JSONObject> iterator = response.getJSONArray("results").iterator();

            while (iterator.hasNext())
                contentSearchResponse.addContent(parseContent(iterator.next()));
        }
    }
}
