/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

public class Tag extends ApiObject {

    private final TagType type;
    private final String displayName;
    private final String webUrl;
    private final String apiUrl;

    private String sectionId;
    private String sectionName;

    Tag(String id, TagType type, String displayName, String webUrl, String apiUrl, String sectionName, String sectionId) {
        this(id, type, displayName, webUrl, apiUrl);
        this.sectionName = sectionName;
        this.sectionId = sectionId;
    }

    Tag(String id, TagType type, String displayName, String webUrl, String apiUrl) {
        super(id);
        this.type = type;
        this.displayName = displayName;
        this.webUrl = webUrl;
        this.apiUrl = apiUrl;
    }

    public String getApiUrl() {
        return apiUrl;
    }

    public String getDisplayName() {
        return displayName;
    }

    public TagType getType() {
        return type;
    }

    public String getWebUrl() {
        return webUrl;
    }

    public String getSectionName() {
        return sectionName;
    }

    public String getSectionId() {
        return sectionId;
    }

    public boolean hasSection() {
        return sectionId != null;
    }

    public boolean isOfType(String typeId) {
        return isOfType(TagType.typeFor(typeId));
    }

    public boolean isOfType(TagType type) {
        return this.type.equals(type);
    }
}
