/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import net.sf.json.JSONException;
import net.sf.json.JSONObject;

import java.util.Iterator;

public class TagJsonParser extends PaginatedJsonParser {

    @Override
    void parseJson(String json, ApiResponse result) {
        super.parseJson(json, result);

        try {
            JSONObject response = extractTopLevelResponse(result, json);
            parseTags((TagSearchResult) result, response);
        }
        catch (JSONException e) {
            result.setStatus(ResponseStatus.error);
        }
    }


    @SuppressWarnings("unchecked")
    private void parseTags(TagSearchResult tagSearchResult, JSONObject response) {
        if (response.has("results")) {
            Iterator<JSONObject> iter = response.getJSONArray("results").iterator();

            while (iter.hasNext())
                tagSearchResult.addTag(parseTag(iter.next()));
        }

    }


}
