/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import java.util.*;

public class TagSearchQuery extends PaginatedSearchQuery<TagSearchQuery> {

    private final Set<TagType> tagTypesToQuery = new HashSet<TagType>();

    public TagSearchQuery(TagJsonParser jsonParser, HttpClient httpClient) {
        super(httpClient, jsonParser);
    }

    @Override
    public TagSearchResult execute() {
        TagSearchResult result = new TagSearchResult(this);

        try {
            jsonParser.parseJson(httpClient.executeQuery("/tags", this), result);
        }
        catch (HttpException e) {
            result.setStatus(ResponseStatus.error);
        }

        return result;
    }

    public TagSearchQuery type(TagType... tagTypes) {
        tagTypesToQuery.addAll(Arrays.asList(tagTypes));
        return this;
    }

    public TagSearchQuery type(String... types) {
        for (String type : types)
            tagTypesToQuery.add(TagType.typeFor(type));

        return this;
    }

    public TagSearchQuery showAllTagTypes() {
        tagTypesToQuery.clear();
        return this;
    }

    @Override
    protected void fillInApiParameters(Map<ApiParameter, Object> parameters) {
        super.fillInApiParameters(parameters);
        addHttpParameter(parameters, ApiParameter.type, getTagTypesToFind());
        addHttpParameter(parameters, ApiParameter.q, getQueryString());
    }

    Set<TagType> getTagTypesToFind() {
        return Collections.unmodifiableSet(tagTypesToQuery);
    }
}

