/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 *   @author Matthew Wall
 **/

package com.gu.openplatform.contentapi;

import java.util.HashSet;
import java.util.Set;

public class TagType implements ApiUrlParameter {

    public static final Set<TagType> allTypes = new HashSet<TagType>();

    public static final TagType keyword = type("keyword");
    public static final TagType blog = type("blog");
    public static final TagType contributor = type("contributor");
    public static final TagType series = type("series");
    public static final TagType tone = type("tone");
    public static final TagType contentType = type("type");

    public static final TagType all = new TagType("all");

    public static TagType typeFor(String type) {
        return new TagType(type);
    }

    private static TagType type(String type) {
        TagType tagType = typeFor(type);
        allTypes.add(tagType);
        return tagType;
    }

    private final String typeParameter;

    TagType(String type) {
        this.typeParameter = type;
    }

    @Override
    public String asApiUrlParameter() {
        return typeParameter;
    }

    @Override
    public int hashCode() {
        return typeParameter.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        return obj != null && obj instanceof TagType && isEqual((TagType) obj);
    }

    @Override
    public String toString() {
        return "TagType [" + typeParameter + "]";
    }

    protected boolean isEqual(TagType tagType) {
        return typeParameter != null && tagType.asApiUrlParameter() != null && asApiUrlParameter().equals(tagType.asApiUrlParameter());
    }
}
