/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.example;

import com.gu.openplatform.contentapi.FirstItemInIndexAwareTest;
import com.gu.openplatform.contentapi.GuardianContentApi;
import com.gu.openplatform.contentapi.ItemResult;
import org.junit.After;
import org.junit.Test;

import java.net.URL;

import static com.gu.openplatform.contentapi.ContentValidator.validateContent;
import static org.junit.Assert.assertTrue;

public class ExampleItemEndpointTest extends FirstItemInIndexAwareTest {

    private ItemResult result;

    @After
    public void tearDown() throws Exception {
        assertTrue(result.isResponseOk());
    }

    @Test
    public void testCanRetriveUrlWithURLObject() throws Exception {
        result = GuardianContentApi
                .itemQuery(new URL(firstItemInIndexApiUrl))
                .execute();

        validateContent(result.getContent());
    }

    @Test
    public void testCanRetrieveItemFromGuardianUrl() throws Exception {
        result = GuardianContentApi
                .itemQuery(firstItemInIndexWebUrn)
                .execute();

        validateContent(result.getContent());
    }

    @Test
    public void testCanRetrieveItemUrlFromFullyQualifiedApiUrlString() throws Exception {
        result = GuardianContentApi
                .itemQuery(firstItemInIndexApiUrl)
                .execute();

        validateContent(result.getContent());
    }

}
