/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.junit.Test;

import java.net.URL;

import static com.gu.openplatform.contentapi.ApiUrlTranslator.canTranslateUrl;
import static com.gu.openplatform.contentapi.ApiUrlTranslator.translateToApiUrl;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.Assert.*;

public class ApiUrlTranslatorTest {

    @Test
    public void testWeUnderstandWhichUrlsCanBeTranslated() throws Exception {
        assertTrue(canTranslateUrl("http://www.guardian.co.uk/commentisfree/2009/sep/30/polly-toynbee-public-service-cuts"));
        assertTrue(canTranslateUrl("/commentisfree/2009/sep/30/polly-toynbee-public-service-cuts"));
        assertFalse(canTranslateUrl("http://www.whelks.com/foo"));
        assertTrue(canTranslateUrl("www.guardian.co.uk/commentisfree/2009/sep/30/polly-toynbee-public-service-cuts"));
        assertTrue(canTranslateUrl(new URL("http://www.guardian.co.uk/foo")));
        assertTrue(canTranslateUrl("/foo"));
    }

    @Test
    public void testCanTranslateUrls() throws Exception {
        assertThat(expectedApiUrl("/foo"), equalTo(translateToApiUrl("http://www.guardian.co.uk/foo").toString()));
        assertThat(expectedApiUrl("/foo"), equalTo(translateToApiUrl("www.guardian.co.uk/foo").toString()));
        assertThat(expectedApiUrl("/foo"), equalTo(translateToApiUrl("/foo").toString()));
        assertThat(expectedApiUrl("/foo"), equalTo(translateToApiUrl(new URL("http://www.guardian.co.uk/foo")).toString()));

        try {
            translateToApiUrl("http://www.whelks.com/foo");
            fail("Should have thrown exception trying to translate invalid URL");
        }
        catch (RuntimeException e) {
            // no-op
        }
    }

    private String expectedApiUrl(String path) {
        return GuardianApiHostProvider.getGuardianApiHost().concat(path);
    }
}
