/**
 *   Copyright 2010 Guardian News And Media
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

abstract class ClasspathFileLoader {

    private static final Logger logger = LoggerFactory.getLogger(ClasspathFileLoader.class);

    static String loadFileContents(String fileName) throws IOException {
        StringBuilder stringBuilder = new StringBuilder();

        if (!fileName.startsWith("/"))
            fileName = "/".concat(fileName);

        if (logger.isTraceEnabled())
            logger.trace("Loading file: " + fileName);

        InputStream stream = ClasspathFileLoader.class.getResourceAsStream(fileName);
        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(stream, "UTF-8"));
        String line;

        while ((line = bufferedReader.readLine()) != null)
            stringBuilder.append(line);

        return stringBuilder.toString();
    }
}
