package com.gu.openplatform.contentapi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Set;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.notNullValue;
import static org.hamcrest.Matchers.startsWith;
import static org.junit.Assert.assertTrue;

public abstract class ContentValidator {

    private static final Logger logger = LoggerFactory.getLogger(ContentValidator.class);

    public static void validateContent(Content content) {
        if (logger.isTraceEnabled())
            logger.trace("Checking " + content);

        assertThat(content.getApiUrl().toString(), startsWith("http://"));
        assertThat(content.getWebUrl().toString(), startsWith("http://"));
        assertThat(content.getId(), notNullValue());
        assertThat(content.getSectionId(), notNullValue());
        assertThat(content.getSectionName(), notNullValue());

        Set<String> fields = content.getFieldNames();

        for (String fieldName : fields)
            assertTrue(content.getField(fieldName) != null);

        if (content.hasTags())
            testTagsOnContentAreWellFormed(content);
    }

    private static void testTagsOnContentAreWellFormed(Content content) {
        for (Tag typeTag : content.getTagsOfType(TagType.contentType))
            assertTrue(content.isOfType(ContentTagType.typeForId(typeTag.getId())));

        for (Tag tag : content.getTags())
            TagValidator.validateTag(tag);
    }
}
