package com.gu.openplatform.contentapi;

import org.hamcrest.Description;
import org.junit.runner.RunWith;
import org.mockito.ArgumentMatcher;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;

import java.net.URL;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@RunWith(MockitoJUnitRunner.class)
abstract class HttpParamsTest {

    @Mock protected HttpQueryExecutor httpQueryExecutor;

    protected HttpParameterValidator expectParameters(HttpParam... parameters) {
        return new HttpParameterValidator(parameters);
    }

    protected class HttpParam {
        protected final String pattern;
        protected final boolean isMultiValue;
        protected final List<String> values;
        protected final ApiParameter parameter;

        protected HttpParam(ApiParameter parameter, String value) {
            this.parameter = parameter;
            pattern = parameter.name() + "=" + UrlEncoder.encode(value);
            isMultiValue = value.indexOf(",") > 0;

            if (isMultiValue)
                values = Arrays.asList(value.split(","));
            else
                values = Arrays.asList(value);
        }

        protected HttpParam(ApiParameter name, ApiUrlParameter value) {
            this(name, value.asApiUrlParameter());
        }

        protected boolean matchesDefinitionFor(HttpParam fromParam) {
            return parameter.equals(fromParam.parameter) && values.containsAll(fromParam.values) && values.size() == fromParam.values.size();
        }
    }

    protected class HttpParameterValidator extends ArgumentMatcher<URL> {
        protected final List<HttpParam> requiredParameters;
        protected HttpParam expectedParam;
        protected String requestedUri;

        protected HttpParameterValidator(HttpParam... parameterPatterns) {
            requiredParameters = Arrays.asList(parameterPatterns);
        }

        @Override
        public boolean matches(Object argument) {
            requestedUri = UrlEncoder.decode(((URL) argument).toExternalForm());
            List<HttpParam> gotParameters = parseUrl(requestedUri);

            for (HttpParam requiredParam : requiredParameters) {
                expectedParam = requiredParam;
                boolean foundMatch = false;

                for (HttpParam gotParam : gotParameters)
                    if (gotParam.matchesDefinitionFor(requiredParam))
                        foundMatch = true;

                if (!foundMatch)
                    return false;
            }

            return true;
        }

        @Override
        public void describeTo(Description description) {
            description.appendText("expected URI to contain [" +
                    UrlEncoder.decode(expectedParam.pattern)
                    + "] was [" +
                    UrlEncoder.decode(requestedUri) + "]");
        }

        protected List<HttpParam> parseUrl(String url) {
            List<HttpParam> parameters = new ArrayList<HttpParam>();
            String queryString = url.substring(url.indexOf("?") + 1);
            String[] queryParams = queryString.split("&");

            for (String queryParamPair : queryParams) {
                String[] queryParam = queryParamPair.split("=");
                parameters.add(new HttpParam(ApiParameter.findByUrlParam(queryParam[0]), queryParam[1]));
            }

            return parameters;
        }
    }
}
