/**
 *   Copyright 2010 Guardian News And Media 
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 **/

package com.gu.openplatform.contentapi;

import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.Assert.fail;

public class TagSearchClientConfigurationTest {

    private TagSearchQuery tagSearchQuery;
    @Mock private TagJsonParser tagJsonParser;
    @Mock private HttpClient httpClient;

    @Before
    public void setUp() throws Exception {
        tagSearchQuery = new TagSearchQuery(tagJsonParser, httpClient);
    }

    @Test
    public void canCreateApiClientWithApiKey() throws Exception {
        tagSearchQuery.apiKey("testapikey");
        assertThat(tagSearchQuery.getApiKey(), equalTo("testapikey"));
    }

    @Test
    public void testCanSetPageStartIndex() throws Exception {
        assertThat(tagSearchQuery.getStartPage(), equalTo(1));
        tagSearchQuery.startPage(5);
        assertThat(tagSearchQuery.getStartPage(), equalTo(5));
    }

    @Test
    public void canConfigurePageSize() throws Exception {
        assertThat(tagSearchQuery.getPageSize(), equalTo(null));

        checkPageSize(1);
        checkPageSize(30);
        checkPageSize(50);

        try {
            checkPageSize(51);
            fail("Should not be able to set page size > 50");
        }
        catch (IllegalArgumentException e) {
            // ok
        }

        try {
            checkPageSize(0);
            fail("Shoult not be able to set page size < 1");
        }
        catch (IllegalArgumentException e) {
            // ok
        }
    }

    @Test
    public void testCanSetSection() throws Exception {
        assertThat(tagSearchQuery.getSection(), equalTo(null));
        tagSearchQuery.section("foo");
        assertThat(tagSearchQuery.getSection(), equalTo("foo"));
    }

    @Test
    public void canCreateContentApiClientWithoutApiKey() throws Exception {
        assertThat(tagSearchQuery.getApiKey(), equalTo(null));
    }

    @Test
    public void canConfigureSearchTerms() throws Exception {
        tagSearchQuery.query("foo");
        assertThat(tagSearchQuery.getQueryString(), equalTo("foo"));

        tagSearchQuery = GuardianContentApi.tagSearchQuery().zeroTermQuery();
        assertThat(tagSearchQuery.getQueryString(), equalTo(null));

        tagSearchQuery = GuardianContentApi.tagSearchQuery();
        assertThat(tagSearchQuery.getQueryString(), equalTo(null));
    }

    private void checkPageSize(Integer pageSize) {
        tagSearchQuery.pageSize(pageSize);
        assertThat(tagSearchQuery.getPageSize(), equalTo(pageSize));
    }
}
