package com.gu.openplatform.contentapi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.hamcrest.Matchers.notNullValue;
import static org.hamcrest.Matchers.nullValue;
import static org.junit.Assert.*;

public abstract class TagValidator {

    private static final Logger logger = LoggerFactory.getLogger(TagValidator.class);

    public static void validateTag(Tag tag) {
        if (logger.isTraceEnabled())
            logger.trace("Checking " + tag);

        try {
            checkUrl(tag.getApiUrl());
            checkUrl(tag.getWebUrl());
            assertThat(tag.getType(), notNullValue());
            assertTrue(TagType.allTypes.contains(tag.getType()));
            assertTrue(tag.isOfType(tag.getType()));
            assertThat(tag.getDisplayName(), notNullValue());
            checkTagSection(tag);
        }
        catch (AssertionError e) {
            logger.error("Tag validation error " + tag);
            throw e;
        }
    }

    private static void checkTagSection(Tag tag) {
        if (tag.isOfType(TagType.keyword)
                || tag.isOfType(TagType.series)
                || tag.isOfType(TagType.blog)) {
            assertTrue(tag.hasSection());
            assertThat(tag.getSectionId(), notNullValue());
            assertThat(tag.getSectionName(), notNullValue());
        } else {
            assertFalse(tag.hasSection());
            assertThat(tag.getSectionId(), nullValue());
            assertThat(tag.getSectionName(), nullValue());
        }
    }

    private static void checkUrl(String value) {
        assertThat(value, notNullValue());
        assertTrue(value.startsWith("http://"));
    }
}
